@@ -7,5 +7,4 @@ from . import repo
 @autocommand.autocommand(__name__)
 def run(project: github.Repo = github.Repo.detect()):
     md = repo.get_project_metadata()
-    tag = f'v{md.version}'
-    project.create_release(tag)
+    project.create_release(tag=f'v{md.version}')
