@@ -2,6 +2,7 @@ import os
 import glob
 import argparse
 import functools
+import re
 
 no_tabs_mode = "# tab-width: 4; indent-tabs-mode: nil;"
 tabs_mode = "# tab-width: 4; indent-tabs-mode: t;"
@@ -87,3 +88,17 @@ def set_tabs_mode_cmd():
     args = parser.parse_args()
     file_names = args.glob(args.spec)
     map(args.tabs_mode, file_names)
+
+
+def to_spaces(script):
+    r"""
+    Replace tab indentation with space indentation.
+
+    >>> to_spaces("\tfoo")
+    '    foo'
+    """
+    return re.sub(r'^\t+', tabs_to_spaces, script, flags=re.MULTILINE)
+
+
+def tabs_to_spaces(tabs):
+    return ' ' * 4 * len(tabs.group(0))
