@@ -1,8 +1,13 @@
+"""
+Facilities for parsing and resolving common merge conflicts.
+"""
+
 import re
 import textwrap
 import contextlib
 from pathlib import Path
 
+from jaraco.functools import identity
 import autocommand
 
 
@@ -72,16 +77,46 @@ class Conflict:
         return orig.replace(self.match.group(0), repl)
 
 
-def resolve_project(conflict):
+def resolve_placeholders(conflict):
     """
     If the text "PROJECT" appears in the conflict on the right,
-    assume the whole conflict is about downstream customization
-    and prefer the downstream (left).
+    prefer upstream (right) but re-substitute the placeholders.
 
-    See jaraco/skeleton#70 for more context.
+    See jaraco/skeleton#70 and jaraco/jaraco.develop#5 for
+    more context.
     """
     assert 'PROJECT' in conflict.right
-    return conflict.left
+    from . import repo
+
+    return _retain_rtd(conflict.left)(repo.sub_placeholders(conflict.right))
+
+
+def _retain_rtd(left):
+    """
+    Retain the RTD enablement.
+
+    If RTD was enabled (uncommented) in left, return a function that
+    will enable it on the right. Otherwise, return a pass-through function.
+
+    >>> _retain_rtd('''.. image:: https://readthedocs.org/...''')
+    <function _enable_rtd at ...>
+    >>> _retain_rtd('''.. .. image:: https://readthedocs.org/...''')
+    <function identity at ...>
+    """
+    enabled = re.search(r'^\.\. image.*readthedocs', left, flags=re.MULTILINE)
+    return _enable_rtd if enabled else identity
+
+
+def _enable_rtd(text):
+    """
+    Given text with a commented RTD badge, uncomment it.
+
+    >>> print(_enable_rtd('''.. .. image:: https://readthedocs.org/...
+    ... ..    :target: https://PROJECT_RTD.readthedocs.io/...'''))
+    .. image:: https://readthedocs.org/...
+       :target: https://PROJECT_RTD.readthedocs.io/...
+    """
+    return re.sub(r'^\.\. ', '', text, flags=re.MULTILINE)
 
 
 def resolve_shebang(conflict):
@@ -91,7 +126,7 @@ def resolve_shebang(conflict):
 
 
 def resolve(conflict):
-    for resolver in (resolve_project, resolve_shebang):
+    for resolver in (resolve_placeholders, resolve_shebang):
         with contextlib.suppress(Exception):
             return resolver(conflict)
     raise ValueError("Unable to resolve")
